==========
Data Types
==========
.. currentmodule:: polars.datatypes

.. autosummary::
    :toctree: api/
    :nosignatures:

    DataType

Numeric
~~~~~~~
.. autosummary::
    :toctree: api/
    :nosignatures:

    Float32
    Float64
    Int16
    Int32
    Int64
    Int8
    UInt16
    UInt32
    UInt64
    UInt8

Date / Time
~~~~~~~~~~~
.. autosummary::
    :toctree: api/
    :nosignatures:

    Date
    Datetime
    Duration
    Time

Nested
~~~~~~
.. autosummary::
    :toctree: api/

    List
    Struct

Other
~~~~~
.. autosummary::
    :toctree: api/
    :nosignatures:

    Boolean
    Categorical
    Null
    Object
    Utf8

Functions
~~~~~~~~~
.. autosummary::
    :toctree: api/

    get_idx_type
